#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_ELLINT_2_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_ELLINT_2_HPP_INCLUDED

#include <nt2/elliptic/include/functions/scalar/ellint_2.hpp>

#endif
